NullablePlatformToggleConverter class

Nullable variant of PlatformToggleConverter.

Unlike PlatformToggleConverter, this converter preserves the "user omitted" vs. "user wrote false" distinction:

Used by PartialConfig whose android/ios fields are intentionally nullable to support later config-merge semantics. Config continues to use the strict PlatformToggleConverter.

Constructors

NullablePlatformToggleConverter()
Creates a converter instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(Object? json) PlatformToggle?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(PlatformToggle? object) Object?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited