ConfigSourceKind enum

Identifies which configuration source flutter_launcher_icons is reading from for a given run.

Inheritance
Available extensions

Values

explicitFile → const ConfigSourceKind

User passed --file <path>.

consolidatedFlavors → const ConfigSourceKind

flutter_launcher_icons_flavors.yaml was found in the prefix dir.

legacyFlavors → const ConfigSourceKind

One or more legacy flutter_launcher_icons-<flavor>.yaml files.

singleFile → const ConfigSourceKind

flutter_launcher_icons.yaml (single-config).

pubspecInline → const ConfigSourceKind

Inline flutter_launcher_icons: (or deprecated flutter_icons:) in pubspec.yaml.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ConfigSourceKind>
A constant List of the values in this enum, in order of their declaration.