NoConfigFoundException class

Exception to be thrown whenever no config is found

Implemented types

Constructors

NoConfigFoundException([String? message])
Constructs instance of this exception
const

Properties

hashCode int
The hash code for this object.
no setterinherited
info String
Short, user-facing message. Printed unconditionally on error.
no setteroverride
message String?
Message for the exception
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose String?
Longer remediation / context, printed under -v/--verbose. May be null when there is nothing extra to add beyond info.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited