MinSdkDetection class
The result of detectMinSdkAndroid.
value is the resolved integer (or null if every probe failed).
matchedLabel is the human-readable label of the matching pattern
(e.g. 'minSdk = N (KTS)'), or null if no app-level gradle pattern
matched (the value, if non-null, then came from local.properties).
Constructors
- MinSdkDetection({required int? value, required String? matchedLabel})
-
Creates a detection result.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- matchedLabel → String?
-
Label of the pattern that matched the app-level gradle file, or
null(no gradle pattern matched, or value came fromlocal.propertiesfallback).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int?
-
Detected minSdk integer, or
nullwhen undetectable.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited