isCustom property
bool
get
isCustom
Whether the user provided a custom icon name (and thus the existing default icon should be preserved).
Implementation
bool get isCustom => _kind == _PlatformToggleKind.named;